%==========================================================================
%
%  Compute 2D integral of a function by applying the 2D trapezoidal
%  integration rule.
%
%   INPUTS:
%     X,Y = Sample locations.
%       f = Fevals at sample points.
%
%   OUPUT:
%       V = Numerical computation using 2D trapezoidal integration.
% 
%       Note that this function assumes uniform grid spacing throughout the
%   entire domain.
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright February 6, 2012

function V = trap_int_2D(X,Y,f)

%  Assume uniform grid spacing.
dx = X(1,2) - X(1,1);
dy = Y(2,1) - Y(1,1);

%  Number of grid samples.
[Ny,Nx] = size(f);

%  2D trapezoid summation consists of 3 parts.  
%   (1) Corners only
%   (2) Edge points
%   (3) The rest of the interior points.
V1 = (dx*dy/4)*( f(1,1) + f(1,Nx) + f(Ny,1) + f(Ny,Nx) );
V2 = (dx*dy/2)*( sum(f(2:Ny-1,1)) + sum(f(2:Ny-1,Nx)) ...
        + sum(f(1,2:Nx-1)) + sum(f(Ny,2:Nx-1)) );
V3 = dx*dy*( sum(sum(f(2:Ny-1,2:Nx-1))) );

%  Now add them all together for total estimated volume.
V = V1 + V2 + V3;


return;


